@@ -40,8 +40,6 @@ typedef enum { /*< underscore_name=gweather_location_level >*/
     GWEATHER_LOCATION_COUNTRY,
     /* ADM1 = first-order administrative division = state/province, etc */
     GWEATHER_LOCATION_ADM1,
-    /* ADM2 = second-order division = county, etc */
-    GWEATHER_LOCATION_ADM2,
     GWEATHER_LOCATION_CITY,
     GWEATHER_LOCATION_WEATHER_STATION,
     GWEATHER_LOCATION_DETACHED,
@@ -65,6 +63,8 @@ const char            *gweather_location_get_name       (GWeatherLocation  *loc)
 GWEATHER_EXTERN
 const char            *gweather_location_get_sort_name  (GWeatherLocation  *loc);
 GWEATHER_EXTERN
+const char            *gweather_location_get_english_name (GWeatherLocation  *loc);
+GWEATHER_EXTERN
 GWeatherLocationLevel  gweather_location_get_level      (GWeatherLocation  *loc);
 GWEATHER_EXTERN
 GWeatherLocation      *gweather_location_get_parent     (GWeatherLocation  *loc);
@@ -147,6 +147,9 @@ GWeatherLocation      *gweather_location_new_detached   (const char        *name
 							 gdouble            latitude,
 							 gdouble            longitude);
 
+GWEATHER_EXTERN
+const char            *gweather_location_level_to_string (GWeatherLocationLevel level);
+
 G_END_DECLS
 
 #endif /* __GWEATHER_LOCATIONS_H__ */
