@@ -34,7 +34,7 @@ G_BEGIN_DECLS
  * @GWEATHER_PROVIDER_NONE: no provider, no weather information available
  * @GWEATHER_PROVIDER_METAR: METAR office, providing current conditions worldwide
  * @GWEATHER_PROVIDER_IWIN: US weather office, providing 7 days of forecast
- * @GWEATHER_PROVIDER_YAHOO: Yahoo Weather Service, worldwide but non commercial only
+ * @GWEATHER_PROVIDER_YAHOO: Yahoo Weather Service, removed in 3.27.1
  * @GWEATHER_PROVIDER_YR_NO: Yr.no service, worldwide but requires attribution
  * @GWEATHER_PROVIDER_OWM: OpenWeatherMap, worldwide and possibly more reliable, but requires attribution and is limited in the number of queries
  * @GWEATHER_PROVIDER_ALL: enable all available providers
@@ -78,8 +78,7 @@ struct _GWeatherInfoClass {
 GWEATHER_EXTERN
 GType                    gweather_info_get_type            (void) G_GNUC_CONST;
 GWEATHER_EXTERN
-GWeatherInfo *           gweather_info_new                 (GWeatherLocation     *location,
-							    GWeatherForecastType  type);
+GWeatherInfo *           gweather_info_new                 (GWeatherLocation *location);
 GWEATHER_EXTERN
 void                     gweather_info_update              (GWeatherInfo *info);
 GWEATHER_EXTERN
@@ -112,9 +111,6 @@ gchar * 		 gweather_info_get_sky		   (GWeatherInfo *info);
 GWEATHER_EXTERN
 gchar *	                 gweather_info_get_conditions	   (GWeatherInfo *info);
 
-GWEATHER_EXTERN G_DEPRECATED_FOR(gweather_info_get_forecast_list)
-gchar *                  gweather_info_get_forecast        (GWeatherInfo *info);
-
 GWEATHER_EXTERN
 gchar * 	  	 gweather_info_get_temp		   (GWeatherInfo *info);
 GWEATHER_EXTERN
